@@ -3,8 +3,8 @@ import sys
 
 
 class InfoFilter(logging.Filter):
-    def filter(self, rec):
-        return rec.levelno in (logging.DEBUG, logging.INFO)
+    def filter(self, record):
+        return record.levelno in (logging.DEBUG, logging.INFO)
 
 class Logger:
     @staticmethod
@@ -21,4 +21,4 @@ class Logger:
         root_logger = logging.getLogger()
         root_logger.setLevel(logging.INFO)
         root_logger.addHandler(std_out_stream_handler)
-        root_logger.addHandler(std_err_stream_handler)
\ No newline at end of file
+        root_logger.addHandler(std_err_stream_handler)
